@@ -46,5 +46,8 @@ def load_cache():
 repo_cache = load_cache()
 
 def dump_cache():
+    if not os.path.isdir("cache"):
+        os.mkdir("cache")
+
     with open("cache/repo_cache.pkl", "wb") as f:
         pickle.dump(repo_cache, f)
\ No newline at end of file
